@@ -12,24 +12,25 @@
 
 sestatus_cmd = '/usr/sbin/sestatus'
 
-# This supports the fact that the selinux mount point is not always in the 
+# This supports the fact that the selinux mount point is not always in the
 # same location -- the selinux mount point is operating system specific.
 def selinux_mount_point
-  if FileTest.exists?('/proc/self/mountinfo')
-    File.open('/proc/self/mountinfo') do |f|
+  path = "/selinux"
+  if FileTest.exists?('/proc/self/mounts')
+    File.open('/proc/self/mounts') do |f|
       f.grep(/selinuxfs/) do |line|
-        line.split[4]
+        path = line.split[1]
+        break
       end
     end
-  else
-    "/selinux"
   end
+  path
 end
 
 Facter.add("selinux") do
   confine :kernel => :linux
   setcode do
-    result = "false" 
+    result = "false"
     if FileTest.exists?("#{selinux_mount_point}/enforce")
       if FileTest.exists?("/proc/self/attr/current")
         if (File.read("/proc/self/attr/current") != "kernel\0")
@@ -56,7 +57,11 @@ end
 Facter.add("selinux_policyversion") do
   confine :selinux => :true
   setcode do
-    File.read("#{selinux_mount_point}/policyvers")
+    result = 'unknown'
+    if FileTest.exists?("#{selinux_mount_point}/policyvers")
+      result = File.read("#{selinux_mount_point}/policyvers").chomp
+    end
+    result
   end
 end
 
@@ -90,7 +95,7 @@ Facter.add("selinux_config_policy") do
   end
 end
 
-# This is a legacy fact which returns the old selinux_mode fact value to prevent 
+# This is a legacy fact which returns the old selinux_mode fact value to prevent
 # breakages of existing manifests. It should be removed at the next major release.
 # See ticket #6677.
 
